#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bug
version:              1.0.1
visibility:           public
id:                   bug-1.0.1-8QeTjccBdQ26Pj6kwD9SSz
key:                  bug-1.0.1-8QeTjccBdQ26Pj6kwD9SSz
license:              MIT
copyright:            (c) 2017, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/bug
synopsis:             Better alternatives to the "error" function
category:             Development, Error Handling
abi:                  b23cf1304e0fdd34136fc489da18fe9d
exposed:              True
exposed-modules:      Bug
hidden-modules:       Bug.Formatting
import-dirs:          /usr/lib/ghc-9.6.6/site-local/bug-1.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/bug-1.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/bug-1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bug
hs-libraries:         HSbug-1.0.1-8QeTjccBdQ26Pj6kwD9SSz
depends:              base-4.18.2.1 template-haskell-2.20.0.0
haddock-interfaces:   /usr/share/doc/haskell-bug/html/bug.haddock
haddock-html:         /usr/share/doc/haskell-bug/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

